@@ -123,8 +123,11 @@ def define_auto(code):
         m = 'public '+str(var_dict.get(code2))+' '+code1+";\n"
         type_Var = str(var_dict.get(code2))
     type_Var2 = type_Var.lower()
-    var_name =var_name.replace(" ","")
-    if var_list.__contains__(var_name):
+    kq = str(var_dict.get(var_name))
+    var_name = var_name.replace(" ","")
+    kq = kq.lower()
+    kq = kq.replace(" ","")
+    if var_list.__contains__(var_name) and kq != type_Var2:
         raise Exception("you already defined in other type")
     if not var_list.__contains__(var_name):
         var_name = var_name.replace(" ","")
